@@ -18,35 +18,32 @@ class Manage:
     The `Manage` class provides the initialization code for the package.
     """
 
-    def __init__(self, app):
+    def __init__(self, app, tag='manage'):
         self._app = app
+        self._tag = tag
+
+        # Register self with the app
+        self._app._manage = self
 
         # Set-up a hidden blueprint to provide access to the templates
         blueprint = flask.Blueprint(
-            '_manhattan_manage',
+            '_manhattan_' + tag,
             __name__,
             template_folder='templates'
             )
         self._app.register_blueprint(blueprint)
 
         # Add filters and functions required by the manage templates
-
-        # If a timezone has been set for the app then we use the timezone to
-        # create a filter that is timezone aware.
-        humanize_datetime = formatters.dates.humanize_datetime
-        if 'TIMEZONE' in app.config:
-            humanize_datetime = humanize_datetime_tz
-
         self._app.jinja_env.filters.update({
             'humanize_date': formatters.dates.humanize_date,
-            'humanize_datetime': humanize_datetime,
+            'humanize_datetime': formatters.dates.humanize_datetime_tz,
             'humanize_duration': formatters.dates.humanize_duration,
             'humanize_status': formatters.text.humanize_status,
             'humanize_timediff': formatters.dates.humanize_timediff,
             'price': formatters.currency.price,
             'text_to_html': formatters.text.text_to_html,
             'yes_no': formatters.text.yes_no
-            })
+        })
 
         # Make the template context available in the template
         @jinja2.contextfunction
@@ -171,6 +168,7 @@ class Manage:
 
         # Build the template
         template = ManageEmailTemplate(
+            self._tag,
             to,
             sender,
             subject,
@@ -198,23 +196,14 @@ class ManageEmailTemplate(EmailTemplate):
     Email template for the manage environment.
     """
 
+    def __init__(self, tag, *args, **kw):
+        self._tag = tag
+        super().__init__(*args, **kw)
+
     def get_jinja_env(self):
         # Return the environment for the manage app
-        manage_app = utils.get_app(flask.current_app._dispatcher)
+        manage_app = utils.get_app(
+            flask.current_app._dispatcher,
+            self._tag
+        )
         return manage_app.jinja_env
-
-
-def humanize_datetime_tz(dt, *args, **kwargs):
-    """A version of `humzanize_datetime` that is timezone aware"""
-    if isinstance(dt, str):
-        dt = formatters.dates.str_to_datetime(dt)
-
-    timezone = pytz.timezone(flask.current_app.config['TIMEZONE'])
-    if dt.tzinfo:
-        dt = dt.astimezone(timezone)
-    else:
-        # We assume that timezone naive datetimes are UTC
-        dt = pytz.utc.localize(dt)
-        dt = dt.astimezone(timezone)
-
-    return formatters.dates.humanize_datetime(dt, *args, **kwargs)
