@@ -3,6 +3,7 @@ from collections import namedtuple
 from .add import add_chains
 from .change_log import change_log_chains
 from .delete import delete_chains
+from .duplicate import duplicate_chains
 from .list import list_chains
 from .order import order_chains
 from .typeahead import typeahead_chains
@@ -39,6 +40,7 @@ Generic = namedtuple(
         'add',
         'change_log',
         'delete',
+        'duplicate',
         'list',
         'order',
         'typeahead',
@@ -54,6 +56,7 @@ generic = Generic(
     add=add_chains,
     change_log=change_log_chains,
     delete=delete_chains,
+    duplicate=duplicate_chains,
     list=list_chains,
     order=order_chains,
     typeahead=typeahead_chains,
